@@ -14,21 +14,25 @@ def rm(filename):
         shutil.rmtree(filename, ignore_errors=True, onerror=None)
 
 
-def copy(src, dst, keep_src_folder_name=True, dst_is_a_folder=False):
-    if os.path.isfile(src):
-        if dst_is_a_folder:
-            src_name = os.path.basename(src)
-            dst_abspath = os.path.join(dst, src_name)
-        else:
-            shutil.copy2(src, dst)
-    else:
-        if keep_src_folder_name:
-            src_name = os.path.basename(src)
-            dst_abspath = os.path.join(dst, src_name)
-            shutil.copytree(src, dst_abspath)
-        else:
-            shutil.copytree(src, dst)
 
+def filecopy(src, dst, dst_is_a_folder=False):
+    if dst_is_a_folder:
+        src_name = os.path.basename(src)
+        dst = os.path.join(dst, src_name)
+    shutil.copy2(src, dst)
+
+def treecopy(src, dst, keep_src_folder_name=True):
+    if keep_src_folder_name:
+        src_name = os.path.basename(src)
+        dst = os.path.join(dst, src_name)
+    shutil.copytree(src, dst)
+
+def copy(src, dst, keep_src_folder_name=True, dst_is_a_folder=False):
+    if os.path.exists(src):
+        if os.path.isfile(src):
+            filecopy(src, dst, dst_is_a_folder)
+        else:
+            treecopy(src, dst, keep_src_folder_name)
 
 def pathjoin(path1, path2):
     return os.path.join(path1, path2)
